# Building Your First Custom Report
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report#prerequisites)
  * [Step 1: Navigate to the Project Directory](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report#step-1:-navigate-to-the-project-directory)
  * [Step 2: Create a Custom Report Module](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report#step-2:-create-a-custom-report-module)
  * [Step 3: Import Fact Sheet Information into the Main Module](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report#step-3:-import-fact-sheet-information-into-the-main-module)
  * [Step 4: Start the Development Server](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report#step-4:-start-the-development-server)
  * [Summary](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report#summary)


Learn how to list your workspace fact sheets using the LeanIX Reporting Library.
